# -*- coding: utf-8 -*-
"""
help_tokens Django application initialization.
"""

from __future__ import absolute_import, unicode_literals

from django.apps import AppConfig


class HelpTokensConfig(AppConfig):
    """
    Configuration for the help_tokens Django application.
    """

    name = 'help_tokens'
